@@ -80,7 +80,7 @@ class ResetPasswordConfirmSerializer(serializers.Serializer):
         """
         Check if passwords matched and if token is valid.
         """
-        validate_token_by_type(data['token'], ActivationCode.CodeTypes.RESET_PASSWORD)
+        data['token'] = validate_token_by_type(data['token'], ActivationCode.CodeTypes.RESET_PASSWORD)
         if data['password'] != data['confirm_password']:
             raise serializers.ValidationError("Passwords does not match")
         return data
@@ -107,7 +107,12 @@ class LoginSerializer(TokenObtainPairSerializer):
 class EBSTokenRefreshSerializer(TokenRefreshSerializer):
     def validate(self, attrs):
         refresh = RefreshToken(attrs['refresh'])
-        user = User.objects.filter(user=refresh.payload.get("user_id")).first()
+
+        user = User.objects.filter(
+            pk=refresh.payload.get("user_id"),
+            service=self.context['request'].service
+        ).first()
+
         if not user:
             raise AuthenticationFailed('User is inactive', code='user_inactive')
 
@@ -117,8 +122,11 @@ class EBSTokenRefreshSerializer(TokenRefreshSerializer):
         if not user.is_confirmed:
             raise AuthenticationFailed('User is not confirmed', code='user_not_confirmed')
 
-        if self.context['request'].get('service'):
-            UserLogs.objects.create(service=self.context['request'].service, user=user,
-                                    username=user, type_log=LogsType.LOGIN_BY_CREDENTIALS)
+        UserLogs.objects.create(
+            service=self.context['request'].service,
+            user=user,
+            username=user,
+            type_log=LogsType.LOGIN_BY_CREDENTIALS
+        )
 
         return super(EBSTokenRefreshSerializer, self).validate(attrs)
