@@ -23,6 +23,14 @@ EMAIL_PASSWORD = getattr(django_settings, 'EMAIL_HOST_PASSWORD')
 EMAIL_USE_TLS = getattr(django_settings, 'EMAIL_USE_TLS')
 
 
+# TODO Auth
+# Delete by username
+# same serializer for register
+# patch to post restore and other actions
+# generate jwt with service secret token
+# return jwt on confirm
+
+
 class ObjDict(dict):
     def __getattribute__(self, item):
         try:
@@ -42,37 +50,37 @@ class ObjDict(dict):
 
 
 default_sso_settings = {
-    "WORK_MODE": "single",
-    "COOKIE_KEY": "single",
-    "DOMAIN_ADDRESS": "drf_auth_service",
+    "WORK_MODE": "standalone",
+    "COOKIE_KEY": "sso_key",
+    "DOMAIN_ADDRESS": None,
     "REFRESH_TOKEN_LIFETIME": timedelta(days=30),
-    "SENDINBLUE_RESET_PASS_TEMPLATE": '',
-    "SENDINBLUE_CONFIRMATION_TEMPLATE": '',
-    "SEND_IN_BLUE_API_KEY": '',
-    "MAILCHIMP_RESET_PASS_TEMPLATE": '',
-    "MAILCHIMP_CONFIRMATION_TEMPLATE": '',
-    "MAILCHIMP_USERNAME": '',
-    "MAILCHIMP_SECRET_KEY": '',
+    "SENDINBLUE_RESET_PASS_TEMPLATE": None,
+    "SENDINBLUE_CONFIRMATION_TEMPLATE": None,
+    "SENDINBLUE_API_KEY": None,
+    "MAILCHIMP_RESET_PASS_TEMPLATE": None,
+    "MAILCHIMP_CONFIRMATION_TEMPLATE": None,
+    "MAILCHIMP_USERNAME": None,
+    "MAILCHIMP_SECRET_KEY": None,
     "SEND_CONFIRMATION": True,
     "RESET_PASSWORD_EXPIRE": 24,
-    "DEFAULT_FROM_NUMBER": '+12055370083',
-    "SEND_RESET_PASSWORD_URL": 'example.com/reset-password',
-    "SEND_CONFIRMATION_URL": 'example.com/confirm-email',
+    "SEND_RESET_PASSWORD_URL": 'https://example.com/reset-password/',
+    "SEND_CONFIRMATION_URL": 'https://example.com/confirm-email/',
     "TWILIO_ACCOUNT_SID": "AC6b3fc1744aa63d35235a4fb01241e71a",
     "TWILIO_AUTH_TOKEN": "a3e0f68829427c69dbb94cb4e95ff638",
-    "SMS_CONFIRMATION_MESSAGE": "Confirmation code {{code}}",
-    "SMS_RESET_PASSWORD_MESSAGE": "Reset password code {{code}}",
+    "TWILIO_FROM_NUMBER": None,
+    "SMS_CONFIRMATION_MESSAGE": "Confirmation code {{ code }}",
+    "SMS_RESET_PASSWORD_MESSAGE": "Reset password code {{ code }}",
     "REGISTER_TYPES": list(dict(RegisterType.choices).keys()),
     "EMAIL_HOST": EMAIL_HOST,
     "EMAIL_PORT": EMAIL_PORT,
     "EMAIL_USERNAME": EMAIL_USERNAME,
     "EMAIL_PASSWORD": EMAIL_PASSWORD,
     "EMAIL_USE_TLS": EMAIL_USE_TLS,
-    "HTML_RESET_PASSWORD_SUBJECT": "Reset password receive",
-    "HTML_DEFAULT_FROM_EMAIL": "info@ebs.com",
-    "HTML_CONFIRMATION_SUBJECT": "Confirmation link",
-    "HTML_EMAIL_RESET_TEMPLATE": "example/path/to/template",
-    "HTML_EMAIL_CONFIRM_TEMPLATE": "example/path/to/template",
+    "HTML_RESET_PASSWORD_SUBJECT": "Reset password",
+    "HTML_DEFAULT_FROM_EMAIL": EMAIL_USERNAME,
+    "HTML_CONFIRMATION_SUBJECT": "Confirm account",
+    "HTML_EMAIL_RESET_TEMPLATE": None,
+    "HTML_EMAIL_CONFIRM_TEMPLATE": None,
     "SERIALIZERS": ObjDict({
         "USER_RETURN_SERIALIZER": "drf_auth_service.users.serializers.ReturnUserBaseSerializer",
         "USER_SERIALIZER": "drf_auth_service.users.serializers.UserBaseSerializer",
@@ -117,14 +125,14 @@ default_sso_settings = {
 MAILCHIMP_REQUIRED_CONFIGS = ["MAILCHIMP_SECRET_KEY", "MAILCHIMP_RESET_PASS_TEMPLATE",
                               "MAILCHIMP_CONFIRMATION_TEMPLATE", "MAILCHIMP_SECRET_KEY"]
 
-SENDINBLUE_REQUIRED_CONFIGS = ["SEND_IN_BLUE_API_KEY", "SENDINBLUE_RESET_PASS_TEMPLATE",
+SENDINBLUE_REQUIRED_CONFIGS = ["SENDINBLUE_API_KEY", "SENDINBLUE_RESET_PASS_TEMPLATE",
                                "SENDINBLUE_CONFIRMATION_TEMPLATE"]
 
 HTML_EMAIL_REQUIRED_CONFIGS = ["HTML_RESET_PASSWORD_SUBJECT", "HTML_CONFIRMATION_SUBJECT", "EMAIL_HOST", "EMAIL_PORT",
                                "EMAIL_USERNAME", "EMAIL_PASSWORD", "EMAIL_USE_TLS", "HTML_EMAIL_RESET_TEMPLATE",
                                "HTML_EMAIL_CONFIRM_TEMPLATE", "HTML_DEFAULT_FROM_EMAIL"]
 
-TWILIO_REQUIRED_CONFIGS = ["TWILIO_ACCOUNT_SID", "TWILIO_AUTH_TOKEN", "DEFAULT_FROM_NUMBER"]
+TWILIO_REQUIRED_CONFIGS = ["TWILIO_ACCOUNT_SID", "TWILIO_AUTH_TOKEN", "TWILIO_FROM_NUMBER"]
 SETTINGS_TO_IMPORT_IN_DB = ["BACKENDS", "REGISTER_TYPES", "SEND_CONFIRMATION", "SMS_RESET_PASSWORD_MESSAGE",
                             "SMS_CONFIRMATION_MESSAGE", ] + SENDINBLUE_REQUIRED_CONFIGS \
                            + MAILCHIMP_REQUIRED_CONFIGS + HTML_EMAIL_REQUIRED_CONFIGS + TWILIO_REQUIRED_CONFIGS
@@ -137,19 +145,48 @@ class Settings:
         if explicit_overriden_settings is None:
             explicit_overriden_settings = {}
 
-        overriden_settings = (
-                getattr(django_settings, SSO_SETTINGS_NAMESPACE, {})
-                or explicit_overriden_settings
-        )
-
+        overriden_settings = (getattr(django_settings, SSO_SETTINGS_NAMESPACE, {}) or explicit_overriden_settings)
         self._load_default_sso_settings()
         self._override_settings(overriden_settings)
         self._validate_configs()
+        self._add_custom_schema_to_swagger()
         try:
             self._init_settings_to_db()
         except:
             pass
 
+    def _add_custom_schema_to_swagger(self):
+        try:
+            from drf_yasg import app_settings
+            swagger_schema = getattr(getattr(django_settings, 'SWAGGER_SETTINGS', {}), 'DEFAULT_AUTO_SCHEMA_CLASS',
+                                     None)
+            if swagger_schema == app_settings.SWAGGER_DEFAULTS['DEFAULT_AUTO_SCHEMA_CLASS'] or swagger_schema is None:
+                app_settings.SWAGGER_DEFAULTS[
+                    'DEFAULT_AUTO_SCHEMA_CLASS'] = 'drf_auth_service.common.mixins.CustomAutoSchema'
+
+            swagger_schema = getattr(getattr(django_settings, 'SWAGGER_SETTINGS', {}), 'SECURITY_DEFINITIONS',
+                                     None)
+            if swagger_schema == app_settings.SWAGGER_DEFAULTS['SECURITY_DEFINITIONS'] or swagger_schema is None:
+                app_settings.SWAGGER_DEFAULTS['SECURITY_DEFINITIONS'] = {
+                    'Bearer': {
+                        'type': 'apiKey',
+                        'name': 'Authorization',
+                        'in': 'header'
+                    },
+                    'Service-Token': {
+                        'type': 'apiKey',
+                        'name': 'Service-Token',
+                        'in': 'header'
+                    },
+                    'Secret-Token': {
+                        'type': 'apiKey',
+                        'name': 'Secret-Token',
+                        'in': 'header'
+                    }
+                }
+        except ModuleNotFoundError:
+            pass
+
     def _load_default_sso_settings(self):
         for setting_name, setting_value in default_sso_settings.items():
             if setting_name.isupper():
@@ -166,7 +203,7 @@ class Settings:
     def _init_settings_to_db(self):
         from drf_auth_service.models import Service, Config
 
-        if getattr(self, 'WORK_MODE') == 'single' and Service.objects.count() == 0:
+        if getattr(self, 'WORK_MODE') == 'standalone' and Service.objects.count() == 0:
             service = Service.objects.create(name='Default configs')
             configs = []
 
