@@ -55,7 +55,7 @@ class UserViewSet(
         user = self.get_user_by_username(request.service, serializer.validated_data['username'])
         UserBlock.objects.create(reason=serializer.validated_data['reason'], user=user)
         return Response(
-            self.get_serializer(dict(message=f"User {serializer['user'].username} was successfully blocked")).data
+            self.get_serializer(dict(message=f"User {user.username} was successfully blocked")).data
         )
 
     @action(detail=False, methods=['POST'], url_path='unblock',
