@@ -17,7 +17,7 @@ def validate_token_by_type(token, code_type):
 
     if timezone.now() > expiry_date:
         reset_password_token.delete()
-        raise ValidationError(dict(token='Token expired'))
+        raise ValidationError(dict(detail='Token expired'))
 
     return reset_password_token
 
